@@ -9,6 +9,7 @@ $VERSION = '0.1';
 
 sub handler {
 	my $r = shift;
+	my $session = Apache::SessionManager::get_session($r);
 	my $str;
 
 	# Main output
@@ -16,7 +17,8 @@ sub handler {
 <HTML>
 <HEAD><TITLE>mod_perl Apache::SessionManager test module</TITLE></HEAD>
 <BODY BGCOLOR="#FFFFFF">
-<CENTER><H1>mod_perl Apache::SessionManager test module</H1></CENTER>
+<CENTER><H1>mod_perl Apache::SessionManager test module</H1>
+<H3>Session start at $$session{'_session_start'}</H3></CENTER>
 <H2>Environment variables:</H2>
 EOM
 	foreach (sort keys %{$r->subprocess_env}) {
@@ -28,6 +30,9 @@ EOM
 		$str .= "<B>$_</B>=" . $r->headers_in->{$_} . "<BR>\n";
 	}
 	$str .= "</BODY>\n</HTML>";
+	
+	# set session value
+	$$session{'random'} = rand;
 		
    # Output code to client
    $r->content_type('text/html'); 
